/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+
#+     Internet Radio Automation & Encoding Toolkit
#+
#+     Copyright (C) 2018, 2019, 2020, 2021, 2022 by Kevin C. O'Kane
#+
#+     Kevin C. O'Kane
#+     kc.okane@gmail.com
#+     https://www.cs.uni.edu/~okane
#+     https://threadsafebooks.com/
#+
#+ This program is free software; you can redistribute it and/or modify
#+ it under the terms of the GNU General Public License as published by
#+ the Free Software Foundation; either version 2 of the License, or
#+ (at your option) any later version.
#+
#+ This program is distributed in the hope that it will be useful,
#+ but WITHOUT ANY WARRANTY; without even the implied warranty of
#+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#+ GNU General Public License for more details.
#+
#+ You should have received a copy of the GNU General Public License
#+ along with this program; if not, write to the Free Software
#+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#+
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//	Feb 23, 2023
//	config_date = Mon Aug  3 15:11:14 EDT 2026

#define _GNU_SOURCE

#include <X11/Xlib.h>
#include <x86_64-linux-gnu/libavformat/avformat.h>
//#include <libavformat/avformat.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <signal.h>
#include <unistd.h>
#include <stdio.h>

#include <string.h>
#include <gtk/gtkx.h>
#include <gtk/gtk.h>
#include <libgen.h>
#include <sys/mman.h>
#include <sys/ioctl.h>
#include <math.h>
#include <ctype.h>
#include <fcntl.h>
#include <linux/videodev2.h>
#include <time.h>
#include <sys/ipc.h>
#include <pulse/pulseaudio.h>
#include <pulse/glib-mainloop.h>
#include <pulse/error.h>
#include <errno.h>
#include <fftw3.h>
#include <vlc/vlc.h>
#include <vlc/libvlc_media_player.h>
#include <vlc/plugins/vlc_plugin.h>

// location of gdk keyboard symbols

#include <gdk/gdkkeysyms.h>

