/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+
#+     Glade / Gtk Programming
#+
#+     Copyright (C) 2020 - 2026 by Kevin C. O'Kane
#+
#+     Kevin C. O'Kane
#+     kc.okane@gmail.com
#+     https://www.cs.uni.edu/~okane
#+     http://threadsafebooks.com/
#+
#+ This program is free software; you can redistribute it and/or modify
#+ it under the terms of the GNU General Public License as published by
#+ the Free Software Foundation; either version 2 of the License, or
#+ (at your option) any later version.
#+
#+ This program is distributed in the hope that it will be useful,
#+ but WITHOUT ANY WARRANTY; without even the implied warranty of
#+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#+ GNU General Public License for more details.
#+
#+ You should have received a copy of the GNU General Public License
#+ along with this program; if not, write to the Free Software
#+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#+
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//	July 8, 2026

#ifndef COMMON_OBJECTS_H
#define COMMON_OBJECTS_H

#define QUOTE "\""

#define mkstr(s) #s

skip = 0;

stack2 = GTK_STACK(gtk_builder_get_object(builder, "stack2"));
sw1 = GTK_WIDGET(gtk_builder_get_object(builder, "sw1"));
stackleft = GTK_STACK(gtk_builder_get_object(builder, "stackleft"));

clip_duration_spinner = GTK_WIDGET(gtk_builder_get_object(builder, "clip_duration_spinner"));

fx12 = GTK_WIDGET(gtk_builder_get_object(builder, "fx12"));

sequential = GTK_WIDGET(gtk_builder_get_object(builder, "sequential"));

duration_spin = GTK_WIDGET(gtk_builder_get_object(builder, "duration_spin"));
crop_adj = GTK_WIDGET(gtk_builder_get_object(builder, "crop_adj"));
insert_panel = GTK_WIDGET(gtk_builder_get_object(builder, "insert_panel"));
adjust_video = GTK_WIDGET(gtk_builder_get_object(builder, "adjust_video"));
Top1 = GTK_WIDGET(gtk_builder_get_object(builder, "Top1"));

opt_panel = GTK_WIDGET(gtk_builder_get_object(builder, "opt_panel"));
ovl_fixed = GTK_WIDGET(gtk_builder_get_object(builder, "ovl_fixed"));
ovl_fixed1 = GTK_WIDGET(gtk_builder_get_object(builder, "ovl_fixed1"));

pg	= GTK_WIDGET(gtk_builder_get_object(builder, "pg"));

message1 = GTK_WIDGET(gtk_builder_get_object(builder, "message1"));

overlay_end_lbl	= GTK_WIDGET(gtk_builder_get_object(builder, "overlay_end_lbl"));
overlay_end	= GTK_WIDGET(gtk_builder_get_object(builder, "overlay_end"));
five_speed 	= GTK_WIDGET(gtk_builder_get_object(builder, "five_speed"));
quad_speed = GTK_WIDGET(gtk_builder_get_object(builder, "quad_speed"));
tripple_speed= GTK_WIDGET(gtk_builder_get_object(builder, "tripple_speed"));
double_speed= GTK_WIDGET(gtk_builder_get_object(builder, "double_speed"));
full_speed= GTK_WIDGET(gtk_builder_get_object(builder, "full_speed"));
half_speed= GTK_WIDGET(gtk_builder_get_object(builder, "half_speed"));
quarter_speed= GTK_WIDGET(gtk_builder_get_object(builder, "quarter_speed"));
eighth_speed= GTK_WIDGET(gtk_builder_get_object(builder, "eighth_speed"));

p1cover			= GTK_WIDGET(gtk_builder_get_object(builder, "p1cover"));
p4cover			= GTK_WIDGET(gtk_builder_get_object(builder, "p4cover"));
p7cover			= GTK_WIDGET(gtk_builder_get_object(builder, "p7cover"));
p7cover			= GTK_WIDGET(gtk_builder_get_object(builder, "p7cover"));
p10cover		= GTK_WIDGET(gtk_builder_get_object(builder, "p10cover"));

clip_x		= GTK_WIDGET(gtk_builder_get_object(builder, "clip_x"));
clip_y		= GTK_WIDGET(gtk_builder_get_object(builder, "clip_y"));

tile_last 		= GTK_WIDGET(gtk_builder_get_object(builder, "tile_last"));

p1name			= GTK_WIDGET(gtk_builder_get_object(builder, "p1name"));
p2name			= GTK_WIDGET(gtk_builder_get_object(builder, "p2name"));
p3name			= GTK_WIDGET(gtk_builder_get_object(builder, "p3name"));
p4name			= GTK_WIDGET(gtk_builder_get_object(builder, "p4name"));
p5name			= GTK_WIDGET(gtk_builder_get_object(builder, "p5name"));
p6name			= GTK_WIDGET(gtk_builder_get_object(builder, "p6name"));
p7name			= GTK_WIDGET(gtk_builder_get_object(builder, "p7name"));
p8name			= GTK_WIDGET(gtk_builder_get_object(builder, "p8name"));
p9name			= GTK_WIDGET(gtk_builder_get_object(builder, "p9name"));
p10name			= GTK_WIDGET(gtk_builder_get_object(builder, "p10name"));
p11name			= GTK_WIDGET(gtk_builder_get_object(builder, "p11name"));
p12name			= GTK_WIDGET(gtk_builder_get_object(builder, "p12name"));

current_dir		= GTK_WIDGET(gtk_builder_get_object(builder, "current_dir"));

p1Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p1Clip"));
p2Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p2Clip"));
p3Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p3Clip"));
p4Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p4Clip"));
p5Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p5Clip"));
p6Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p6Clip"));
p7Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p7Clip"));
p8Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p8Clip"));
p9Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p9Clip"));
p10Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p10Clip"));
p11Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p11Clip"));
p12Clip			= GTK_WIDGET(gtk_builder_get_object(builder, "p12Clip"));

frames_per_second	= GTK_WIDGET(gtk_builder_get_object(builder, "frames_per_second"));
play_clip1		= GTK_WIDGET(gtk_builder_get_object(builder, "play_clip1"));
frame_forward1		= GTK_WIDGET(gtk_builder_get_object(builder, "frame_forward1"));
frame_forward2		= GTK_WIDGET(gtk_builder_get_object(builder, "frame_forward2"));
loop_stream		= GTK_WIDGET(gtk_builder_get_object(builder, "loop_stream"));
out_fade		= GTK_WIDGET(gtk_builder_get_object(builder, "out_fade"));
in_fade			= GTK_WIDGET(gtk_builder_get_object(builder, "in_fade"));
granularity		= GTK_WIDGET(gtk_builder_get_object(builder, "granularity"));
zippy_toy		= GTK_WIDGET(gtk_builder_get_object(builder, "zippy_toy"));
pgedit_back		= GTK_WIDGET(gtk_builder_get_object(builder, "pgedit_back"));
pgedit_back1		= GTK_WIDGET(gtk_builder_get_object(builder, "pgedit_back1"));
rantran			= GTK_WIDGET(gtk_builder_get_object(builder, "rantran"));
select_all		= GTK_WIDGET(gtk_builder_get_object(builder, "select_all"));
clear_all		= GTK_WIDGET(gtk_builder_get_object(builder, "clear_all"));
monochrome		= GTK_WIDGET(gtk_builder_get_object(builder, "monochrome"));
sharp_x			= GTK_WIDGET(gtk_builder_get_object(builder, "sharp_x"));
sharp_y			= GTK_WIDGET(gtk_builder_get_object(builder, "sharp_y"));
sharp_amount		= GTK_WIDGET(gtk_builder_get_object(builder, "sharp_amount"));
text_end		= GTK_WIDGET(gtk_builder_get_object(builder, "text_end"));
text_start		= GTK_WIDGET(gtk_builder_get_object(builder, "text_start"));
text_label		= GTK_WIDGET(gtk_builder_get_object(builder, "text_label"));
text_color		= GTK_COLOR_BUTTON(gtk_builder_get_object(builder, "text_color"));
edge_canny		= GTK_WIDGET(gtk_builder_get_object(builder, "edge_canny"));
edge_wires		= GTK_WIDGET(gtk_builder_get_object(builder, "edge_wires"));
edge_colormix		= GTK_WIDGET(gtk_builder_get_object(builder, "edge_colormix"));
view_log		= GTK_WIDGET(gtk_builder_get_object(builder, "view_log"));
dbox4_tv		= GTK_WIDGET(gtk_builder_get_object(builder, "dbox4_tv"));
dbox4_vp		= GTK_WIDGET(gtk_builder_get_object(builder, "dbox4_vp"));
dbox4_sw		= GTK_WIDGET(gtk_builder_get_object(builder, "dbox4_sw"));
// clip_length		= GTK_WIDGET(gtk_builder_get_object(builder, "clip_length"));
top1_back1		= GTK_WIDGET(gtk_builder_get_object(builder, "top1_back1"));
join_group23		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group23"));
join_group22		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group22"));
join_group21		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group21"));
join_group20		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group20"));
join_group18		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group18"));
join_group19		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group19"));
join_group17		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group17"));
join_group16		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group16"));
join_group15		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group15"));
join_group14		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group14"));
join_group13		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group13"));
join_group12		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group12"));
join_group11		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group11"));
join_group10		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group10"));
join_group9		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group9"));
join_group8		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group8"));
join_group7		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group7"));
join_group6		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group6"));
join_group5		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group5"));
join_group4		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group4"));
join_group3		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group3"));
join_group2		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group2"));
join_group1		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group1"));
join_group		= GTK_WIDGET(gtk_builder_get_object(builder, "join_group"));
vid_custom		= GTK_WIDGET(gtk_builder_get_object(builder, "vid_custom"));
vid_640x480		= GTK_WIDGET(gtk_builder_get_object(builder, "vid_640x480"));
vid_720x480		= GTK_WIDGET(gtk_builder_get_object(builder, "vid_720x480"));
vid_1280x720		= GTK_WIDGET(gtk_builder_get_object(builder, "vid_1280x720"));
vid_1920x1080		= GTK_WIDGET(gtk_builder_get_object(builder, "vid_1920x1080"));
vid_3840x2160		= GTK_WIDGET(gtk_builder_get_object(builder, "vid_3840x2160"));
crop_left		= GTK_WIDGET(gtk_builder_get_object(builder, "crop_left"));
crop_right		= GTK_WIDGET(gtk_builder_get_object(builder, "crop_right"));
crop_top		= GTK_WIDGET(gtk_builder_get_object(builder, "crop_top"));
crop_bottom		= GTK_WIDGET(gtk_builder_get_object(builder, "crop_bottom"));
frame_next		= GTK_WIDGET(gtk_builder_get_object(builder, "frame_next"));
full_speed		= GTK_WIDGET(gtk_builder_get_object(builder, "full_speed"));
posLbl			= GTK_WIDGET(gtk_builder_get_object(builder, "posLbl"));
strip_audio		= GTK_WIDGET(gtk_builder_get_object(builder, "strip_audio"));
snapshot		= GTK_WIDGET(gtk_builder_get_object(builder, "snapshot"));
join_videos		= GTK_WIDGET(gtk_builder_get_object(builder, "join_videos"));
frame_grab		= GTK_WIDGET(gtk_builder_get_object(builder, "frame_grab"));
crop_full		= GTK_WIDGET(gtk_builder_get_object(builder, "crop_full"));
crop_reset		= GTK_WIDGET(gtk_builder_get_object(builder, "crop_reset"));
clear_clip		= GTK_WIDGET(gtk_builder_get_object(builder, "clear_clip"));
pg_edit			= GTK_WIDGET(gtk_builder_get_object(builder, "pg_edit"));
pg_fixed			= GTK_WIDGET(gtk_builder_get_object(builder, "pg_fixed"));
ct_fixed		= GTK_WIDGET(gtk_builder_get_object(builder, "ct_fixed"));
ed_fixed		= GTK_WIDGET(gtk_builder_get_object(builder, "ed_fixed"));
make_clip		= GTK_WIDGET(gtk_builder_get_object(builder, "make_clip"));
end_mark		= GTK_WIDGET(gtk_builder_get_object(builder, "end_mark"));
start_mark		= GTK_WIDGET(gtk_builder_get_object(builder, "start_mark"));
mini_mode		= GTK_WIDGET(gtk_builder_get_object(builder, "mini_mode"));
time_of_day		= GTK_WIDGET(gtk_builder_get_object(builder, "time_of_day"));
adjustment1		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment1"));
adjustment40		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment40"));
adjustment54		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment54"));
adjustment6		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment6"));
adjustment7		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment7"));
adjustment8		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment8"));
adjustment9		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment9"));
adjustment10		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment10"));
adjustment11		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment11"));
adjustment12		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment12"));
adjustment13		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment13")); // back_trans
adjustment14		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment14")); // text_start
adjustment15		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment15")); // text_end
adjustment16		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment16")); // text_size
adjustment20		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment20")); // granularity
adjustment21		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment21")); // loop stream
adjustment22		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment22")); // incr secs
adjustment23		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment23")); // incr secs
adjustment25		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment25")); // clip coord
adjustment26		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment26")); // clip coord
adjustment27		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment27")); // audio level
adjustment28		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment28")); // clip speed
adjustment29		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment29")); // clip speed
adjustment30		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment30")); // clip speed
adjustment31		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment31")); // clip speed
adjustment32		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment32")); // clip speed
adjustment33		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment33")); // clip speed
adjustment43		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment43")); // clip speed
adjustment37		= GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment37")); // clip scale
audio			= GTK_WIDGET(gtk_builder_get_object(builder, "audio"));
background		= GTK_WIDGET(gtk_builder_get_object(builder, "background"));
button10		= GTK_WIDGET(gtk_builder_get_object(builder, "button10"));
button11		= GTK_WIDGET(gtk_builder_get_object(builder, "button11"));
button12		= GTK_WIDGET(gtk_builder_get_object(builder, "button12"));
button13		= GTK_WIDGET(gtk_builder_get_object(builder, "button13"));
button14		= GTK_WIDGET(gtk_builder_get_object(builder, "button14"));
button15		= GTK_WIDGET(gtk_builder_get_object(builder, "button15"));
button2			= GTK_WIDGET(gtk_builder_get_object(builder, "button2"));
button3			= GTK_WIDGET(gtk_builder_get_object(builder, "button3"));
button5			= GTK_WIDGET(gtk_builder_get_object(builder, "button5"));
button6			= GTK_WIDGET(gtk_builder_get_object(builder, "button6"));
button8			= GTK_WIDGET(gtk_builder_get_object(builder, "button8"));
button9			= GTK_WIDGET(gtk_builder_get_object(builder, "button9"));
calibrateLbl		= GTK_WIDGET(gtk_builder_get_object(builder, "calibrateLbl"));
cbox1			= GTK_WIDGET(gtk_builder_get_object(builder, "cbox1"));
check10			= GTK_WIDGET(gtk_builder_get_object(builder, "check10"));
check11			= GTK_WIDGET(gtk_builder_get_object(builder, "check11"));
check12			= GTK_WIDGET(gtk_builder_get_object(builder, "check12"));
check1			= GTK_WIDGET(gtk_builder_get_object(builder, "check1"));
check2			= GTK_WIDGET(gtk_builder_get_object(builder, "check2"));
check3			= GTK_WIDGET(gtk_builder_get_object(builder, "check3"));
check4			= GTK_WIDGET(gtk_builder_get_object(builder, "check4"));
check5			= GTK_WIDGET(gtk_builder_get_object(builder, "check5"));
check6			= GTK_WIDGET(gtk_builder_get_object(builder, "check6"));
check7			= GTK_WIDGET(gtk_builder_get_object(builder, "check7"));
check8          	= GTK_WIDGET(gtk_builder_get_object(builder, "check8"));
check9          	= GTK_WIDGET(gtk_builder_get_object(builder, "check9"));
choose1         	= GTK_WIDGET(gtk_builder_get_object(builder, "choose1"));
classical       	= GTK_WIDGET(gtk_builder_get_object(builder, "classical"));
clevel          	= GTK_WIDGET(gtk_builder_get_object(builder, "clevel"));
club            	= GTK_WIDGET(gtk_builder_get_object(builder, "club"));
controls        	= GTK_WIDGET(gtk_builder_get_object(builder, "controls"));
dance           	= GTK_WIDGET(gtk_builder_get_object(builder, "dance"));
del10           	= GTK_WIDGET(gtk_builder_get_object(builder, "del10"));
del11           	= GTK_WIDGET(gtk_builder_get_object(builder, "del11"));
del12           	= GTK_WIDGET(gtk_builder_get_object(builder, "del12"));
del13           	= GTK_WIDGET(gtk_builder_get_object(builder, "del13"));
del14           	= GTK_WIDGET(gtk_builder_get_object(builder, "del14"));
del15           	= GTK_WIDGET(gtk_builder_get_object(builder, "del15"));
del2            	= GTK_WIDGET(gtk_builder_get_object(builder, "del2"));
del3            	= GTK_WIDGET(gtk_builder_get_object(builder, "del3"));
del4            	= GTK_WIDGET(gtk_builder_get_object(builder, "del4"));
del7            	= GTK_WIDGET(gtk_builder_get_object(builder, "del7"));
del8            	= GTK_WIDGET(gtk_builder_get_object(builder, "del8"));
del9            	= GTK_WIDGET(gtk_builder_get_object(builder, "del9"));
drawV           	= GTK_WIDGET(gtk_builder_get_object(builder, "drawV"));
draw3           	= GTK_WIDGET(gtk_builder_get_object(builder, "draw3"));
clip_markers           	= GTK_WIDGET(gtk_builder_get_object(builder, "clip_markers"));
empty           	= GTK_WIDGET(gtk_builder_get_object(builder, "empty"));
OverlayEntry1         	= GTK_ENTRY(gtk_builder_get_object(builder, "OverlayEntry1"));
OverlayEntry2         	= GTK_ENTRY(gtk_builder_get_object(builder, "OverlayEntry2"));
OverlayEntry3         	= GTK_ENTRY(gtk_builder_get_object(builder, "OverlayEntry3"));
OverlayEntry4         	= GTK_ENTRY(gtk_builder_get_object(builder, "OverlayEntry4"));
OverlayEntry5         	= GTK_ENTRY(gtk_builder_get_object(builder, "OverlayEntry5"));
eqReset         	= GTK_WIDGET(gtk_builder_get_object(builder, "eqReset"));
first           	= GTK_WIDGET(gtk_builder_get_object(builder, "first"));
fixed1          	= GTK_WIDGET(gtk_builder_get_object(builder, "fixed1"));
fixed2          	= GTK_WIDGET(gtk_builder_get_object(builder, "fixed2"));
fixed_slides    	= GTK_WIDGET(gtk_builder_get_object(builder, "fixed_slides"));
g_btn_play      	= GTK_WIDGET(gtk_builder_get_object(builder, "button1"));
g_dbox5Entry    	= GTK_ENTRY(gtk_builder_get_object(builder,  "dbox5Entry"));
g_dbox4         	= GTK_WIDGET(gtk_builder_get_object(builder, "dbox4"));
haltProgram     	= GTK_WIDGET(gtk_builder_get_object(builder, "haltProgram"));
highLabel       	= GTK_WIDGET(gtk_builder_get_object(builder, "highLabel"));
horLabel        	= GTK_WIDGET(gtk_builder_get_object(builder, "horLabel"));
lbl10           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl10"));
lbl11           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl11"));
lbl12           	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl12"));
lbl1            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl1"));
lbl2            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl2"));
lbl3            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl3"));
lbl4            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl4"));
lbl5            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl5"));
lbl6            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl6"));
lbl7            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl7"));
lbl8            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl8"));
lbl9            	= GTK_WIDGET(gtk_builder_get_object(builder, "lbl9"));
live            	= GTK_WIDGET(gtk_builder_get_object(builder, "live"));
more            	= GTK_WIDGET(gtk_builder_get_object(builder, "more"));
rayLbl          	= GTK_WIDGET(gtk_builder_get_object(builder, "rayLbl"));
scroll          	= GTK_WIDGET(gtk_builder_get_object(builder, "scroll"));
sgrStudio       	= GTK_WIDGET(gtk_builder_get_object(builder, "sgrStudio"));
sort1            	= GTK_WIDGET(gtk_builder_get_object(builder, "sort1"));
source          	= GTK_WIDGET(gtk_builder_get_object(builder, "source"));
vlcPosition     	= GTK_WIDGET(gtk_builder_get_object(builder, "vlcPosition"));

extern GtkWidget *Bars;
Bars			= GTK_WIDGET(gtk_builder_get_object(builder, "Bars"));

extern GtkWidget *draw1;
draw1			= GTK_WIDGET(gtk_builder_get_object(builder, "draw1"));

extern GtkWidget *draw2;
draw2			= GTK_WIDGET(gtk_builder_get_object(builder, "draw2"));

extern GtkWidget *fixed1a;
fixed1a			= GTK_WIDGET(gtk_builder_get_object(builder, "fixed1a"));

extern GtkWidget *Spectrum;
Spectrum		= GTK_WIDGET(gtk_builder_get_object(builder, "Spectrum"));

extern GtkWidget *meters;
meters			= GTK_WIDGET(gtk_builder_get_object(builder, "meters"));

extern GtkWidget *balance;
balance			= GTK_WIDGET(gtk_builder_get_object(builder, "balance"));


p10             	= GTK_WIDGET(gtk_builder_get_object(builder, "p10"));
p11             	= GTK_WIDGET(gtk_builder_get_object(builder, "p11"));
p12             	= GTK_WIDGET(gtk_builder_get_object(builder, "p12"));
p1              	= GTK_WIDGET(gtk_builder_get_object(builder, "p1"));
p2              	= GTK_WIDGET(gtk_builder_get_object(builder, "p2"));
p3              	= GTK_WIDGET(gtk_builder_get_object(builder, "p3"));
p4              	= GTK_WIDGET(gtk_builder_get_object(builder, "p4"));
p5              	= GTK_WIDGET(gtk_builder_get_object(builder, "p5"));
p6              	= GTK_WIDGET(gtk_builder_get_object(builder, "p6"));
p7              	= GTK_WIDGET(gtk_builder_get_object(builder, "p7"));
p8              	= GTK_WIDGET(gtk_builder_get_object(builder, "p8"));
p9              	= GTK_WIDGET(gtk_builder_get_object(builder, "p9"));

nowPlaying             	= GTK_WIDGET(gtk_builder_get_object(builder, "nowPlaying"));

scroll2         	= GTK_WIDGET(gtk_builder_get_object(builder, "scroll2"));

search_scroll   	= GTK_WIDGET(gtk_builder_get_object(builder, "search_scroll"));



#endif
